@@ -61,7 +61,7 @@
 #define KIRIGAMI2_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KIRIGAMI2_NO_DEPRECATED
-#  define KIRIGAMI2_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56e00
+#  define KIRIGAMI2_DISABLE_DEPRECATED_BEFORE_AND_AT 0x57300
 #endif
 #ifdef KIRIGAMI2_NO_DEPRECATED_WARNINGS
 #  define KIRIGAMI2_DEPRECATED_WARNINGS_SINCE 0
@@ -71,7 +71,7 @@
 #  ifdef KIRIGAMI2_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KIRIGAMI2_DEPRECATED_WARNINGS_SINCE KIRIGAMI2_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KIRIGAMI2_DEPRECATED_WARNINGS_SINCE 0x56e00
+#    define KIRIGAMI2_DEPRECATED_WARNINGS_SINCE 0x57300
 #  endif
 #endif
 
